@@ -1,26 +1,21 @@
 from __future__ import annotations
 
 import warnings
-from collections.abc import MutableSequence
-from typing import TYPE_CHECKING, Iterable, Iterator, List, Optional, overload
+from typing import Iterable, Iterator, List, MutableSequence, Optional, overload
 
-from attr import define, field
+from attrs import define, field
 from fontTools.pens.basePen import AbstractPen
 from fontTools.pens.pointPen import AbstractPointPen, PointToSegmentPen
 
 from ufoLib2.objects.misc import BoundingBox, getBounds, getControlBounds
 from ufoLib2.objects.point import Point
+from ufoLib2.serde import serde
 from ufoLib2.typing import GlyphSet
 
-# For Python 3.7 compatibility.
-if TYPE_CHECKING:
-    ContourMapping = MutableSequence[Point]
-else:
-    ContourMapping = MutableSequence
-
 
+@serde
 @define
-class Contour(ContourMapping):
+class Contour(MutableSequence[Point]):
     """Represents a contour as a list of points.
 
     Behavior:
@@ -59,8 +54,7 @@ class Contour(ContourMapping):
         del self.points[index]
 
     @overload
-    def __getitem__(self, index: int) -> Point:
-        ...
+    def __getitem__(self, index: int) -> Point: ...
 
     @overload
     def __getitem__(self, index: slice) -> list[Point]:  # noqa: F811
